#include "./scrabblelcd.h"

//Initialize the lcd display
void scrabbleLCDinit() {
	initLCD();
	setPos(0,0);
	putrsXLCD("         |");
	setPos(0,10);
	putrsXLCD("         |");
	setPos(0,20);
	putrsXLCD("         |");
	setPos(0,30);
	putrsXLCD("         |");

	setPos(1,1);
	putrsXLCD("        |");
	setPos(1,11);
	putrsXLCD("        |");	
	setPos(1,21);
	putrsXLCD("        |");	
	setPos(1,31);
	putrsXLCD("        |");	
	
	setPos(2, 0);
	putrsXLCD("Enter the number of players (2-4): ");
    setPos(2, 35);
}

//Initialize the set time state on the lcd
void scrabbleLCDinitSetTimeMode(void) {
	clearLine(2);
	clearLine(3);
	putrsXLCD("   Enter Timelimit in Seconds:");
}

//Initialize the ready state on the lcd
void scrabbleLCDinitReadyMode(void) {
	clearLine(2);
	putrsXLCD("Ready.");
}

//Initialize run mode on the lcd
void scrabbleLCDinitRunMode(void) {
	clearLine(2);	
	clearLine(3);
	setPos(2, ENTER_SCORE_VALUE_POS - 13);
	putrsXLCD("Enter Score:");
}

//For name entry, place the cursor in the appropriate spot
//playernum goes from 0 to 3
//charnum goes from 0 to PLAYER_NAME_LENGTH-1
void placeCursor(int playernum, int charnum) {
	setPos(1, playernum*10 + charnum);
	cursorOn();
}

//For name entry, place the character in the appropriate spot
void placeChar(int playernum, int charnum, char c) {
	setPos(1, playernum*10 + charnum);
	cursorOn();
	putchar(c);
	setPos(1, playernum*10 + charnum);
}

//Turn the cursor on
void cursorOn(void){
	delayMicro(160);
	WriteCmdXLCD(CURSOR_ON);
}

//Turn the cursor off (doesn't work)
void cursorOff(void){
	delayMicro(160);
	WriteCmdXLCD(CURSOR_OFF);
}

//Given the time in seconds, display it
void dispTimeSecs(int playernum, int secs) {
	dispTime(playernum, secs/60, secs%60);
}

//Display the time left
void dispTime(int playernum, int mins, int secs) {
	char buff[10];
	setPos(3,0);
	putrsXLCD("      "); //6 spaces cleared
	setPos(3,0);
	itoa(mins, buff);
	putsXLCD(buff);
	itoa(secs,buff);
	putchar(':');
	if (secs < 10) putchar('0');
	putsXLCD(buff);
}

//Display the time bar given the time left and total time
void dispTimeBar(int mins, int secs, int totalmins, int totalsecs) {
	float ratio = ((60*mins + secs) / (60 * totalmins + totalsecs));
	dispTimeBarRatio(ratio);
}

//Display the time bar with only a certain percentage filled in
void dispTimeBarRatio(float ratio) {
	int i, length;
	setPos(3,((40-TIME_START_COL-6-TIME_BAR_LENGTH)/2)+TIME_START_COL+6);
	cursorOff();
	length = (int)(ratio * TIME_BAR_LENGTH);
	for(i=0; i<length; i++) {
		putchar(0xff); //block
	}
	for(i=length; i<TIME_BAR_LENGTH; i++) {
		putchar('-'); //dash
	}
}

//Display the scores for all players
void dispScores(player_info_t *players, int numplayers) {
	int i;
	for (i = 0; i < numplayers; i++) {
		setScore(i, players[i].score);
		setBingos(i, players[i].last_score);
	}
}

//Display the score for this player
void setScore(int playernum, int score) {
	int i;
	char buff[10];
	setPos(1, playernum*10 + 4);
	cursorOff();
	for (i=0; i<NUM_DIGITS_SCORE; i++) putchar(' ');
	setPos(1, playernum*10 + 4);
	itoa(score, buff);
	putsXLCD(buff);
}

//We no longer display bingos
//this instead displays the last score
void setBingos(int playernum, int bingos) {
	int i;
	char buff[10];
	setPos(0, playernum*10 + 4);
	cursorOff();
	for (i=0; i<NUM_DIGITS_BINGOS; i++) putchar(' ');
	setPos(0, playernum*10 + 4);
	itoa(bingos, buff);
	putsXLCD(buff);
}

//Update the asterisk indicating the player's turn
void setPlayerTurn(int playernum) {
	int i;
	for (i=0; i<4; i++) {
		setPos(0, 1+i*10);
		putchar(' ');
	}
	setPos(0, 1+playernum*10);
	putchar('*');
	setPos(0, 3+playernum*10);
}
